@@ -1,4 +1,4 @@
-/* $Id: irplib_polynomial.c,v 1.34 2012-02-03 14:54:06 llundin Exp $
+/* $Id: irplib_polynomial.c,v 1.35 2013-01-29 08:43:33 jtaylor Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2004 European Southern Observatory
@@ -15,13 +15,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012-02-03 14:54:06 $
- * $Revision: 1.34 $
+ * $Author: jtaylor $
+ * $Date: 2013-01-29 08:43:33 $
+ * $Revision: 1.35 $
  * $Name: not supported by cvs2svn $
  */
 
@@ -112,174 +112,6 @@ static double irplib_polynomial_depress_1d(cpl_polynomial *);
                               Function codes
  -----------------------------------------------------------------------------*/
 
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE > CPL_VERSION(5, 92, 0)
-#else
-
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Add two polynomials of the same dimension
-  @param    self      The polynomial to hold the result
-  @param    first     The 1st polynomial to add
-  @param    second    The 2nd polynomial to add
-  @return   CPL_ERROR_NONE or the relevant CPL error code
-  @note self may be passed also as first and/or second
-
-  Possible CPL error code set in this function:
-  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
-  - CPL_ERROR_INCOMPATIBLE_INPUT if the polynomials do not have identical
-    dimensions
-  - CPL_ERROR_UNSUPPORTED_MODE if the dimension is not 1 (FIXME)
- */
-/*----------------------------------------------------------------------------*/
-cpl_error_code irplib_polynomial_add(cpl_polynomial * self,
-                                     const cpl_polynomial * first,
-                                     const cpl_polynomial * second)
-{
-    cpl_size       degree0 = cpl_polynomial_get_degree(self);
-    const cpl_size degree1 = cpl_polynomial_get_degree(first);
-    const cpl_size degree2 = cpl_polynomial_get_degree(second);
-    const cpl_size maxdeg  = degree1 > degree2 ? degree1 : degree2;
-
-
-    cpl_ensure_code(self   != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(first  != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(second != NULL, CPL_ERROR_NULL_INPUT);
-
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) ==
-                    cpl_polynomial_get_dimension(first),
-                    CPL_ERROR_INCOMPATIBLE_INPUT);
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) ==
-                    cpl_polynomial_get_dimension(second),
-                    CPL_ERROR_INCOMPATIBLE_INPUT);
-
-    /* FIXME: */
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) == 1,
-                    CPL_ERROR_UNSUPPORTED_MODE);
-
-    if (degree0 < maxdeg) {
-        degree0 = maxdeg;
-    } else {
-        /* Reset coefficients in self as needed */
-        for (; degree0 > maxdeg; degree0--) {
-            cpl_polynomial_set_coeff(self, &degree0, 0.0);
-        }
-    }
-
-    /* assert( degree0 == maxdeg ); */
-
-    for (; degree0 >= 0; degree0--) {
-        const double val1 = cpl_polynomial_get_coeff(first, &degree0);
-        const double val2 = cpl_polynomial_get_coeff(second, &degree0);
-        cpl_polynomial_set_coeff(self, &degree0, val1 + val2);
-    }
-
-    return CPL_ERROR_NONE;
-}
-
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Subtract two polynomials of the same dimension
-  @param    self      The polynomial to hold the result
-  @param    first     The polynomial to subtract from
-  @param    second    The polynomial to subtract
-  @return   CPL_ERROR_NONE or the relevant CPL error code
-  @note self may be passed also as first and/or second
-
-  Possible CPL error code set in this function:
-  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
-  - CPL_ERROR_INCOMPATIBLE_INPUT if the polynomials do not have identical
-    dimensions
-  - CPL_ERROR_UNSUPPORTED_MODE if the dimension is not 1 (FIXME)
- */
-/*----------------------------------------------------------------------------*/
-cpl_error_code irplib_polynomial_subtract(cpl_polynomial * self,
-                                          const cpl_polynomial * first,
-                                          const cpl_polynomial * second)
-{
-    cpl_size       degree0 = cpl_polynomial_get_degree(self);
-    const cpl_size degree1 = cpl_polynomial_get_degree(first);
-    const cpl_size degree2 = cpl_polynomial_get_degree(second);
-    const cpl_size maxdeg  = degree1 > degree2 ? degree1 : degree2;
-
-
-    cpl_ensure_code(self   != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(first  != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(second != NULL, CPL_ERROR_NULL_INPUT);
-
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) ==
-                    cpl_polynomial_get_dimension(first),
-                    CPL_ERROR_INCOMPATIBLE_INPUT);
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) ==
-                    cpl_polynomial_get_dimension(second),
-                    CPL_ERROR_INCOMPATIBLE_INPUT);
-
-    /* FIXME: */
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) == 1,
-                    CPL_ERROR_UNSUPPORTED_MODE);
-
-    if (degree0 < maxdeg) {
-        degree0 = maxdeg;
-    } else {
-        /* Reset coefficients in self as needed */
-        for (; degree0 > maxdeg; degree0--) {
-            cpl_polynomial_set_coeff(self, &degree0, 0.0);
-        }
-    }
-
-    /* assert( degree0 == maxdeg ); */
-
-    for (; degree0 >= 0; degree0--) {
-        const double val1 = cpl_polynomial_get_coeff(first, &degree0);
-        const double val2 = cpl_polynomial_get_coeff(second, &degree0);
-        cpl_polynomial_set_coeff(self, &degree0, val1 - val2);
-    }
-
-    return CPL_ERROR_NONE;
-}
-
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Multiply a polynomial with a scalar
-  @param    self      The polynomial to hold the result
-  @param    other     The polynomial to scale, may equal self
-  @param    factor    The factor to multiply with
-  @return   CPL_ERROR_NONE or the relevant CPL error code
-
-  Possible CPL error code set in this function:
-  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
-  - CPL_ERROR_UNSUPPORTED_MODE if the dimension is not 1 (FIXME)
- */
-/*----------------------------------------------------------------------------*/
-cpl_error_code irplib_polynomial_multiply_scalar(cpl_polynomial * self,
-                                                 const cpl_polynomial * other,
-                                                 double factor)
-{
-
-    const cpl_size maxdeg  = cpl_polynomial_get_degree(other);
-    const cpl_size zerodeg = cpl_polynomial_get_degree(self);
-    cpl_size       degree;
-
-    cpl_ensure_code(self  != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(other != NULL, CPL_ERROR_NULL_INPUT);
-
-    cpl_ensure_code(cpl_polynomial_get_dimension(self) == 1,
-                    CPL_ERROR_UNSUPPORTED_MODE);
-    cpl_ensure_code(cpl_polynomial_get_dimension(other) == 1,
-                    CPL_ERROR_UNSUPPORTED_MODE);
-
-    for (degree = 0; degree <= maxdeg; degree++) {
-        const double val = factor * cpl_polynomial_get_coeff(other, &degree);
-        cpl_polynomial_set_coeff(self, &degree, val);
-    }
-
-    /* Reset coefficients in self as needed */
-    for (; degree <= zerodeg; degree++) {
-        cpl_polynomial_set_coeff(self, &zerodeg, 0.0);
-    }
-
-    return CPL_ERROR_NONE;
-}
-#endif
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Compute all n roots of p(x) = 0, where p(x) is of degree n, n > 0.
@@ -347,6 +179,7 @@ cpl_error_code irplib_polynomial_solve_1d_all(const cpl_polynomial * self,
   @param    roots A pre-allocated vector of length n to hold the roots
   @param    preal The number of real roots found, or undefined on error
   @return   CPL_ERROR_NONE or the relevant CPL error code
+  @note There is no support for more than 4 complex roots
 
   The *preal real roots are stored first in ascending order, then follows for
   each pair of complex conjugate roots, the real and imaginary parts of the
@@ -825,7 +658,7 @@ static cpl_boolean irplib_polynomial_solve_1d_3(double p3, double p2, double p1,
 
         if (resx <= res) {
             is_first = CPL_FALSE;
-            res = resx;
+            /*res = resx;*/
             x1 = xx1;
             x2 = xx2;
             x3 = xx3;
@@ -1065,9 +898,9 @@ static void irplib_polynomial_solve_1d_3r(double a, double c,
 
     /* -1.0 <= cos((theta + CPL_MATH_2PI) / 3.0) <= -0.5
        -0.5 <= cos((theta - CPL_MATH_2PI) / 3.0) <=  0.5
-        0.5 <= cos((theta                  ) / 3.0) <=  1.0 */
+        0.5 <= cos((theta               ) / 3.0) <=  1.0 */
 
-#define TR1 (-2.0 * sqrtQ * cos( theta                    / 3.0))
+#define TR1 (-2.0 * sqrtQ * cos( theta                 / 3.0))
 #define TR2 (-2.0 * sqrtQ * cos((theta - CPL_MATH_2PI) / 3.0))
 #define TR3 (-2.0 * sqrtQ * cos((theta + CPL_MATH_2PI) / 3.0))
 
