@@ -230,6 +230,8 @@ visir_img_reduce_fill_parameterlist(cpl_parameterlist * self)
             continue;
         if (strstr(name, "compress"))
             continue;
+        if (strstr(name, "ncycles"))
+            continue;
         cpl_parameterlist_append(self, visir_parameter_duplicate(p));
     }
 
@@ -344,7 +346,7 @@ run_phot(cpl_recipe * phot, cpl_frameset *photset,
 
     skip_if(0);
 
-    cpl_frame_set_tag(imgf, "IM_CAL_PHOT_PREPROCESSED");
+    cpl_frame_set_tag(imgf, VISIR_IMG_CAL_PHOT_PP);
     cpl_frameset_insert(photset, imgf);
     cpl_frame_set_tag(wgtf, VISIR_UTIL_WEIGHT_MAP_PROCATG);
     cpl_frameset_insert(photset, wgtf);
@@ -389,6 +391,7 @@ static int visir_img_reduce(cpl_frameset            * framelist,
     cpl_recipe * phot = NULL;
     cpl_pluginlist * plugins = cpl_pluginlist_new();
     cpl_frameset * usedframes = cpl_frameset_new();
+    cpl_frame * meanfrm = NULL;
 
     skip_if(check_swarp());
 
@@ -418,7 +421,8 @@ static int visir_img_reduce(cpl_frameset            * framelist,
     }
     skip_if(visir_run_recipe(repack, repackset, parlist,
                              &util_repack_set_parameters));
-    cpl_frame * meanfrm = cpl_frame_duplicate(cpl_frameset_find(repackset, "MEAN"));
+    meanfrm = cpl_frame_duplicate(cpl_frameset_find(repackset,
+                                            VISIR_UTIL_REPACK_MEAN_PROCATG));
 
 
     cpl_frameset * shiftset = visir_prepare_frameset(repackset, NULL, 0,
@@ -432,23 +436,25 @@ static int visir_img_reduce(cpl_frameset            * framelist,
     shiftset = visir_remove_modified_calib(shiftset);
 
 
-    const char * tagmap[] = {"BEAM_DETECTED", VISIR_UTIL_INPUTS_RAW};
+    const char * tagmap[] = {VISIR_UTIL_DETECT_SHIFT_PROCATG, VISIR_UTIL_INPUTS_RAW};
     cpl_frameset * clipset =
         visir_prepare_frameset(shiftset, tagmap, ARRAY_LEN(tagmap), CPL_FALSE);
     skip_if(visir_run_recipe(clip, clipset, parlist, &visir_copy_parameters));
 
 
-    const char * qctagmap[] = {"BEAM_DETECTED", VISIR_UTIL_CORRECTED};
+    const char * qctagmap[] = {VISIR_UTIL_DETECT_SHIFT_PROCATG, VISIR_UTIL_CORRECTED};
     cpl_frameset * qcset = visir_prepare_frameset(shiftset, qctagmap,
                                                   ARRAY_LEN(qctagmap),
                                                   CPL_FALSE);
     skip_if(visir_run_recipe(qc, qcset, parlist, &visir_copy_parameters));
 
 
-    const char * swarptagmap[] = {"BEAM_DETECTED", VISIR_UTIL_CORRECTED};
+    const char * swarptagmap[] = {VISIR_UTIL_DETECT_SHIFT_PROCATG, VISIR_UTIL_CORRECTED};
     cpl_frameset * swarpset = visir_prepare_frameset(shiftset, swarptagmap,
                                                      ARRAY_LEN(swarptagmap),
                                                      CPL_FALSE);
+    cpl_frameset_delete(shiftset);
+    shiftset = NULL;
     FOR_EACH_FRAMESET(frm, clipset) {
         if (strcmp(cpl_frame_get_tag(frm), VISIR_UTIL_ERROR_MAP) != 0)
             continue;
@@ -456,6 +462,8 @@ static int visir_img_reduce(cpl_frameset            * framelist,
         cpl_frame_set_group(frame, CPL_FRAME_GROUP_RAW);
         cpl_frameset_insert(swarpset, frame);
     }
+    cpl_frameset_delete(clipset);
+    clipset = NULL;
     skip_if(visir_run_recipe(swarp, swarpset, parlist, &visir_copy_parameters));
     irplib_framelist * swarpfl = irplib_framelist_cast(swarpset);
     irplib_framelist * qcfl = irplib_framelist_cast(qcset);
@@ -469,8 +477,8 @@ static int visir_img_reduce(cpl_frameset            * framelist,
         qcs = irplib_framelist_new();
         cpl_errorstate_set(cleanstate);
     }
-    cpl_frame * coadd_imgf = cpl_frameset_find(swarpset, "COADDED_IMAGE_COMBINED");
-    cpl_frame * coadd_wgtf = cpl_frameset_find(swarpset, "COADDED_WEIGHT_COMBINED");
+    cpl_frame * coadd_imgf = cpl_frameset_find(swarpset, VISIR_IMG_COADDED_IMG);
+    cpl_frame * coadd_wgtf = cpl_frameset_find(swarpset, VISIR_IMG_COADDED_WGT);
     skip_if(coadd_imgf == NULL || coadd_wgtf == NULL);
 
 
@@ -544,19 +552,21 @@ static int visir_img_reduce(cpl_frameset            * framelist,
                 cpl_frameset_insert(framelist, cpl_frame_duplicate(frm));
         cpl_frameset_delete(joinset);
         cpl_frameset_insert(framelist, meanfrm);
+        meanfrm = NULL;
         skip_if(0);
     }
 
     end_skip;
 
     {
-        cpl_recipe * recipes[] = {repack, shift, clip, qc, swarp, phot};
+        cpl_recipe * recipes[] = {repack, shift, clip, qc, swarp, phot, join};
         for (size_t i = 0; i < ARRAY_LEN(recipes); i++)
             if (recipes[i])
                 cpl_plugin_delete(&(recipes[i]->interface));
     }
     cpl_pluginlist_delete(plugins);
 
+    cpl_frame_delete(meanfrm);
     cpl_frameset_delete(photset);
     cpl_frameset_delete(usedframes);
 
