@@ -372,6 +372,7 @@ static int visir_spc_reduce(cpl_frameset            * framelist,
     const char * input_tag;
 
     visir_dfs_set_groups(framelist);
+    cpl_frame * linframe = NULL;
     FOR_EACH_FRAMESET(frame_, framelist) {
         cpl_frame * frame = cpl_frame_duplicate(frame_);
         cpl_frameset_insert(usedframes, cpl_frame_duplicate(frame));
@@ -379,8 +380,13 @@ static int visir_spc_reduce(cpl_frameset            * framelist,
             !strcmp(cpl_frame_get_tag(frame), VISIR_SPEC_CAL_LINES_PROCATG) ||
             !strcmp(cpl_frame_get_tag(frame), VISIR_SPEC_CAL_QEFF_PROCATG))
             cpl_frameset_insert(obsset, frame);
-        else
+        else {
+            /* linearity correction also passed to undistort */
+            if (!strcmp(cpl_frame_get_tag(frame), VISIR_CALIB_LIN)) {
+                linframe = cpl_frame_duplicate(frame);
+            }
             cpl_frameset_insert(repackset, frame);
+        }
     }
     nrep = cpl_frameset_get_size(repackset);
     if (cpl_frameset_find(repackset, VISIR_CALIB_LIN)) {
@@ -417,6 +423,10 @@ static int visir_spc_reduce(cpl_frameset            * framelist,
     /* jitter correction modifies input calib file and adds a new one
      * to the recipe output, so drop the original one from the frameset */
     undistset = visir_remove_modified_calib(undistset);
+    /* insert linearity table for skyframe*/
+    if (linframe) {
+        cpl_frameset_insert(undistset, linframe);
+    }
     cpl_frameset_delete(repackset);
     repackset = NULL;
     skip_if(visir_run_recipe(undist, undistset, parlist,
