@@ -320,8 +320,8 @@ static int visir_old_spc_obs(cpl_frameset            * framelist,
 
     visir_data_type data_type;
     const cpl_frame * frm = irplib_framelist_get_const(rawframes, 0);
-    cpl_propertylist * plist = irplib_framelist_get_propertylist(rawframes, 0);
-    skip_if(visir_get_data_type(frm, plist, &data_type, NULL));
+    skip_if(visir_get_data_type(frm,
+         irplib_framelist_get_propertylist(rawframes, 0), &data_type, NULL));
 
     if (visir_data_is_drs(data_type)) {
         /* if parameters are (aqu) defaults and drs data use old parameters */
