@@ -234,9 +234,9 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
     skip_if(0);
 
     visir_data_type data_type;
-    cpl_propertylist * plist = irplib_framelist_get_propertylist(rawframes, 0);
     const cpl_frame * frm = irplib_framelist_get_const(rawframes, 0);
-    skip_if(visir_get_data_type(frm, plist, &data_type, NULL));
+    skip_if(visir_get_data_type(frm,
+           irplib_framelist_get_propertylist(rawframes, 0), &data_type, NULL));
 
     /* Standard star catalog */
     star_cat = irplib_frameset_find_file(framelist, VISIR_CALIB_STDSTAR_SPC);
