@@ -106,7 +106,7 @@ cpl_error_code visir_util_detect_shift_one(cpl_frameset *,
                                            cpl_mask *,
                                            visir_plane **);
 
-#ifdef _OPENMP
+#ifdef VISIR_OMP3
 static double t_loading = 0.;
 static double t_loading_blocked = 0.;
 static double t_handling_blocked_in = 0.;
@@ -163,6 +163,7 @@ static void visir_plane_delete(visir_plane * pl)
     }
 }
 
+#ifdef _OPENMP
 static inline int
 pl_compare_seqnb(const visir_plane * a, const visir_plane * b)
 {
@@ -172,6 +173,7 @@ pl_compare_seqnb(const visir_plane * a, const visir_plane * b)
         return 1;
     return 0;
 }
+#endif
 
 static void planelist_delete(cx_list * l)
 {
@@ -585,8 +587,7 @@ load_range(const cpl_frame *frame, cpl_size * start, cpl_size nplanes,
     if (visir_imglist_get_size(range) > 1) {
         /* approximation assuming non padded header and all extensions have
          * similar compression, take first extension as primary has no data */
-        cpl_propertylist * plist = visir_imglist_get_data(range, 1);
-        size_t nbytes = visir_get_nbytes_plist(plist);
+        size_t nbytes = visir_get_nbytes_plist(visir_imglist_get_data(range, 1));
         visir_drop_cache(filename, 0, nbytes * (*start));
     }
 
