@@ -48,11 +48,11 @@
 #define RECIPE_STRING   "visir_util_repack"
 
 #define VISIR_DRS_CONAD      "ESO DET OUT1 CONAD"
-typedef enum nodtype_e {
+enum nodtype_e {
     ANOD,
     BNOD,
     ABNOD
-} nodtype;
+};
 
 
 /*-----------------------------------------------------------------------------
@@ -138,7 +138,6 @@ visir_util_repack_two(const repack_framestate * fstatea,
                       cpl_frameset * products,
                       cpl_image ** pbpm,
                       cpl_image * nonlinear,
-                      double, double,
                       const cpl_bivector * lintab);
 
 static inline cpl_error_code
@@ -329,6 +328,14 @@ visir_util_repack_fill_parameterlist(cpl_parameterlist * self)
                                         " type results.");
     cpl_ensure_code(!err, err);
 
+    /* --lincorrect */
+    err = irplib_parameterlist_set_bool(self, PACKAGE, RECIPE_STRING,
+                                    "lincorrect", CPL_FALSE, NULL, context,
+                                    "Apply linearity correction. Should "
+                                    "only be enabled on high flux observations"
+                                    ", may degrade results otherwise.");
+    cpl_ensure_code(!err, err);
+
     return CPL_ERROR_NONE;
 }
 
@@ -356,6 +363,7 @@ repack_framestate_new(irplib_framelist * rawframes, int iframe,
     cpl_size next;
     state->time_max_filewrite = -1;
     state->time_min_obsstart = 1e300;
+    cpl_errorstate cleanstate = cpl_errorstate_get();
 
     state->rawframes = rawframes;
 
@@ -510,9 +518,6 @@ repack_framestate_new(irplib_framelist * rawframes, int iframe,
     state->remregexp  = "^(" VISIR_PFITS_DOUBLE_CUMOFFSETX
                         "|" VISIR_PFITS_DOUBLE_CUMOFFSETY ")$";
 
-    /* Get the chopping throw in pixels */
-    state->pthrow = visir_pfits_get_chop_pthrow(state->plist);
-    state->posang = visir_pfits_get_chop_posang(state->plist);
 
     state->pfov = visir_pfits_get_pixscale(state->plist);
 
@@ -591,12 +596,59 @@ repack_framestate_new(irplib_framelist * rawframes, int iframe,
                                        CPL_DFS_FITS, 1+iframe);
     }
 
+    /* Get the chopping throw in pixels */
+    state->pthrow = visir_pfits_get_chop_pthrow(state->plist);
+    state->posang = visir_pfits_get_chop_posang(state->plist) -
+                    visir_pfits_get_ada_posang(state->plist);
+
+    const char * chopnod_dir = visir_pfits_get_chopnod_dir(state->plist);
+    /* can be missing for old spec data */
+    if (chopnod_dir == NULL) {
+        chopnod_dir = "PARALLEL";
+        cpl_errorstate_set(cleanstate);
+    }
+
+    /* compute jitter offset */
+    if (strcmp(visir_pfits_get_insmode(state->plist), "IMG") == 0) {
+        if (strcmp(chopnod_dir, "PARALLEL") == 0) {
+            state->posang -= 90 * CPL_MATH_RAD_DEG;
+        }
+    }
+    else if (strncmp(visir_pfits_get_insmode(state->plist), "SPC", 3) == 0) {
+        /* spc detector is always parallel and rotated another 90 degree */
+        state->posang -= 180 * CPL_MATH_RAD_DEG;
+    }
+    else {
+        cpl_errorstate_set(cleanstate);
+        cpl_msg_warning(cpl_func, "Unknown INS MODE %s",
+                        visir_pfits_get_insmode(state->plist));
+    }
+    if (!state->is_a) {
+        state->offsetx -= cos(state->posang) * state->pthrow;// - sin(state->posang) * state->pthrow;
+        state->offsety += sin(state->posang) * state->pthrow;// + cos(state->posang) * state->pthrow;
+    }
+
+    /* spectrograph rotation also swaps -x and y */
+    if (visir_data_is_aqu(state->datatype) &&
+        strncmp(visir_pfits_get_insmode(state->plist), "SPC", 3) == 0) {
+        double tmp = state->offsety;
+        state->offsety = -state->offsetx;
+        state->offsetx = tmp;
+    }
+
+
+    /* remove rounding errors on no jitter */
+    state->offsetx = fabs(state->offsetx) < 0.001 ? 0. : state->offsetx;
+    state->offsety = fabs(state->offsety) < 0.001 ? 0. : state->offsety;
+    cpl_msg_info(cpl_func, "POSANG: %g; Offset: (%g, %g); Throw: %g; "
+                 "Jitterwidth %g", state->posang * CPL_MATH_DEG_RAD, state->offsetx,
+                 state->offsety, state->pthrow, state->jitterwidth);
+
     {
         long nx, ny;
         if (state->datatype == VISIR_DATA_AQU_HCYCLE ||
             state->datatype == VISIR_DATA_AQU_INT ||
             state->datatype == VISIR_DATA_AQU_BURST_EXT) {
-            cpl_errorstate cleanstate = cpl_errorstate_get();
             cpl_propertylist * plist = cpl_propertylist_load(filename, 1);
             nx = visir_pfits_get_naxis1(plist);
             ny = visir_pfits_get_naxis2(plist);
@@ -800,7 +852,6 @@ static int visir_util_repack(cpl_frameset            * framelist,
     cpl_size nmean[] = {0, 0, 0, 0};
     visir_sub_type bkgcorrect = VISIR_SUB_NOCORRECT;
     visir_frame_type * frametype = NULL;
-    double xjitter0, yjitter0;
     int planelimit = 0, nreduced = 0;
 
     /* Identify the RAW and CALIB frames in the input frameset */
@@ -894,17 +945,15 @@ static int visir_util_repack(cpl_frameset            * framelist,
             frm = cpl_frameset_find(framelist, VISIR_CALIB_STATIC_MASK_SPC);
         }
         repack_framestate * state = ((repack_framestate*)cx_list_front(alist));
-        yjitter0 = ((repack_framestate*)cx_list_front(alist))->offsety;
         if (frm) {
-            bpm = cpl_image_load(cpl_frame_get_filename(frm),
-                                 CPL_TYPE_UNSPECIFIED, 0, 0);
+            bpm = visir_load_bpm(frm, state->datatype,
+                                 strncmp(visir_pfits_get_insmode(state->plist),
+                                         "SPC", 3) == 0);
             if (bpm == NULL) {
                 cpl_msg_warning(cpl_func, "Loading of bad pixel map %s failed",
                                 cpl_frame_get_filename(frm));
                 skip_if(0);
             }
-            cpl_msg_info(cpl_func, "Loaded bad pixel mask from %s",
-                         cpl_frame_get_filename(frm));
             if (visir_data_is_aqu(state->datatype)) {
                 cpl_size win_nx = visir_pfits_get_win_nx(state->plist);
                 cpl_size win_ny = visir_pfits_get_win_ny(state->plist);
@@ -934,46 +983,24 @@ static int visir_util_repack(cpl_frameset            * framelist,
         }
     }
 
-    xjitter0 = ((repack_framestate*)cx_list_front(alist))->offsetx;
-    yjitter0 = ((repack_framestate*)cx_list_front(alist))->offsety;
-
-    {
+    /* off by default, not accurate enough to work on low count signal data */
+    if (irplib_parameterlist_get_bool(parlist, PACKAGE, RECIPE_STRING,
+                                      "lincorrect")) {
         repack_framestate * st = cx_list_front(alist);
-        const char * lextname = NULL;
-        if (visir_is_img(st->plist)) {
-            lextname = "IMAGE_LIN";
-        }
-        else if (visir_is_spc(st->plist)) {
-            lextname = "SPEC_LIN";
-        }
         cpl_frame * frm = cpl_frameset_find(framelist, VISIR_CALIB_LIN);
-        if (lextname && frm && visir_data_is_aqu(st->datatype)) {
-            const char * fn = cpl_frame_get_filename(frm);
-            cpl_msg_info(cpl_func, "Correcting linearity using %s extension "
-                         "of %s", lextname, fn);
-            cpl_size iext = cpl_fits_find_extension(fn, lextname);
-            error_if(iext < 0, CPL_ERROR_ILLEGAL_INPUT,
-                     "Linearity correction extension %s not found in %s",
-                     lextname, fn);
-
-            cpl_table * tab = cpl_table_load(fn, iext, 0);
-            const size_t n = cpl_table_get_nrow(tab);
-            lintable = cpl_bivector_new(n);
-            memcpy(cpl_bivector_get_x_data(lintable),
-                   cpl_table_get_data_double(tab, "dc_level"),
-                   sizeof(double) * n);
-            memcpy(cpl_bivector_get_y_data(lintable),
-                   cpl_table_get_data_double(tab, "conv_gain"),
-                   sizeof(double) * n);
-            cpl_table_delete(tab);
-
-            /* normalize by average */
-            cpl_vector_divide_scalar(cpl_bivector_get_y(lintable),
-                     cpl_vector_get_mean(cpl_bivector_get_y(lintable)));
+        error_if(frm == NULL, CPL_ERROR_INCOMPATIBLE_INPUT,
+                 "Linearity correction requested by no input file tagged "
+                 "with LINEARITY_TABLE");
+        if (visir_data_is_aqu(st->datatype)) {
+            if (visir_is_img(st->plist)) {
+                lintable = visir_load_lintable(frm, CPL_FALSE);
+            }
+            else if (visir_is_spc(st->plist)) {
+                lintable = visir_load_lintable(frm, CPL_TRUE);
+            }
         }
     }
 
-
     while (1) {
         repack_framestate * fstatea = NULL, * fstateb = NULL;
         if (!cx_list_empty(alist))
@@ -1041,7 +1068,7 @@ static int visir_util_repack(cpl_frameset            * framelist,
         OMP_PRAGMA(omp single)
         {
             visir_util_repack_two(fstatea, fstateb, framelist, &bpm, nonlinear,
-                                  xjitter0, yjitter0, lintable);
+                                  lintable);
         }
         skip_if(0);
 
@@ -1390,6 +1417,7 @@ equalize_lists(cpl_imagelist * a, cpl_imagelist * b)
 static cpl_error_code
 check_and_fix_cd_wcs(const repack_framestate * state, cpl_propertylist * plist)
 {
+    cpl_errorstate cleanstate = cpl_errorstate_get();
     /* move wcs from extension to primary as needed by detect_shift
      * but only if primary does not already have wcs as then the ext is wrong
      * (aqu data < 2016.02) */
@@ -1425,18 +1453,21 @@ check_and_fix_cd_wcs(const repack_framestate * state, cpl_propertylist * plist)
         cpl_propertylist_update_string(plist, "CUNIT2",
                                        cpl_array_get_string(v, 1));
     }
-    if (!cpl_propertylist_has(plist, "CD1_1") ||
-        cpl_propertylist_get_double(plist, "CD1_1") == 0.) {
+    cpl_boolean invalid =
+        (cpl_propertylist_get_double(plist, "CD1_1") == 0. &&
+         cpl_propertylist_get_double(plist, "CD1_2") == 0.) ||
+        (cpl_propertylist_get_double(plist, "CD2_1") == 0. &&
+         cpl_propertylist_get_double(plist, "CD2_2") == 0.);
+    invalid = invalid || (cpl_error_get_code() != CPL_ERROR_NONE);
+    cpl_errorstate_set(cleanstate);
+
+    if (invalid) {
         double pfov = visir_pfits_get_pixscale(state->plist);
-        cpl_msg_warning(cpl_func, "CD1_1 WCS key missing or zero, fixing to "
-                        "%g (pfov) / 3600", -pfov);
+        cpl_msg_warning(cpl_func, "CDX_Y WCS key missing or zero, fixing to "
+                        "%g (pfov) / 3600", pfov);
         cpl_propertylist_update_double(plist, "CD1_1", -pfov / 3600.);
-    }
-    if (!cpl_propertylist_has(plist, "CD2_2") ||
-        cpl_propertylist_get_double(plist, "CD2_2") == 0.) {
-        double pfov = visir_pfits_get_pixscale(state->plist);
-        cpl_msg_warning(cpl_func, "CD2_2 WCS key missing or zero, fixing to "
-                        "%g (-pfov) / 3600", pfov);
+        cpl_propertylist_update_double(plist, "CD1_2", 0.);
+        cpl_propertylist_update_double(plist, "CD2_1", 0.);
         cpl_propertylist_update_double(plist, "CD2_2", pfov / 3600.);
     }
 
@@ -1461,10 +1492,8 @@ check_and_fix_cd_wcs(const repack_framestate * state, cpl_propertylist * plist)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code
 prepare_output(const repack_framestate * state, cpl_frameset * products,
-               double xjittera, double yjittera,
-               double xjitterb, double yjitterb,
                double bg_mean,
-               int nodtype)
+               enum nodtype_e nodtype)
 {
     cpl_frameset  * usedframes = cpl_frameset_new();
     cpl_propertylist * onlist  = cpl_propertylist_new();
@@ -1488,8 +1517,8 @@ prepare_output(const repack_framestate * state, cpl_frameset * products,
             VISIR_DRS_CUMOFFSETXA : VISIR_DRS_CUMOFFSETX;
         const char * keyy = nodtype == ABNOD ?
             VISIR_DRS_CUMOFFSETYA : VISIR_DRS_CUMOFFSETY;
-        cpl_propertylist_append_double(onlist, keyx, xjittera);
-        cpl_propertylist_append_double(onlist, keyy, yjittera);
+        cpl_propertylist_append_double(onlist, keyx, state->offsetx);
+        cpl_propertylist_append_double(onlist, keyy, state->offsety);
         cpl_propertylist_set_comment(onlist, keyx, state->comoffx);
         cpl_propertylist_set_comment(onlist, keyy, state->comoffy);
     }
@@ -1499,8 +1528,8 @@ prepare_output(const repack_framestate * state, cpl_frameset * products,
             VISIR_DRS_CUMOFFSETXB : VISIR_DRS_CUMOFFSETX;
         const char * keyy = nodtype == ABNOD ?
             VISIR_DRS_CUMOFFSETYB : VISIR_DRS_CUMOFFSETY;
-        cpl_propertylist_append_double(onlist, keyx, xjitterb);
-        cpl_propertylist_append_double(onlist, keyy, yjitterb);
+        cpl_propertylist_append_double(onlist, keyx, state->offsetx);
+        cpl_propertylist_append_double(onlist, keyy, state->offsety);
         cpl_propertylist_set_comment(onlist, keyx, state->comoffx);
         cpl_propertylist_set_comment(onlist, keyy, state->comoffy);
     }
@@ -1730,10 +1759,6 @@ correct_linearity(const repack_framestate * state,
  * @param aoff    nod a off list empty after return
  * @param bon     nod b on list  empty after return
  * @param boff    nod b off list empty after return
- * @param dxa     jitter x offset of nod a, used only for mean
- * @param dya     jitter y offset of nod b, used only for mean
- * @param dxb     jitter x offset of nod a, used only for mean
- * @param dyb     jitter y offset of nod b, used only for mean
  * @param last_chunk  whether processing last chunk
  */
 /* ---------------------------------------------------------------------------*/
@@ -1744,8 +1769,6 @@ save_corrected(const repack_framestate * fstatea,
                cpl_imagelist * aoff,
                cpl_imagelist * bon,
                cpl_imagelist * boff,
-               double dxa, double dya,
-               double dxb, double dyb,
                const cpl_boolean last_chunk)
 {
     cpl_imagelist * chop_corrected_a, * chop_corrected_b;
@@ -1777,12 +1800,12 @@ save_corrected(const repack_framestate * fstatea,
             cpl_imagelist_divide_scalar(chop_corrected_b, 2);
         }
 
-        if (visir_round_to_int(dxa) != 0 ||
-            visir_round_to_int(dya) != 0 ||
-            visir_round_to_int(dxb) != 0 ||
-            visir_round_to_int(dyb) != 0) {
-            jca = correct_jitter(chop_corrected_a, dxa, dya);
-            jcb = correct_jitter(chop_corrected_b, dxb, dyb);
+        if (visir_round_to_int(fstatea->offsetx) != 0 ||
+            visir_round_to_int(fstatea->offsety) != 0 ||
+            visir_round_to_int(fstateb->offsetx) != 0 ||
+            visir_round_to_int(fstateb->offsety) != 0) {
+            jca = correct_jitter(chop_corrected_a, fstatea->offsetx, fstatea->offsety);
+            jcb = correct_jitter(chop_corrected_b, fstateb->offsetx, fstateb->offsety);
             cpl_imagelist_subtract(jca, jcb);
         }
 
@@ -1838,8 +1861,6 @@ save_uncorrected(const repack_framestate * fstatea,
   @param    fstateb     nodpos B frame state
   @param    products    products frameset
   @param    pbpm        pointer to static bpm, extracted from cube data once
-  @param    xjitter0    x-jitter in pixels of the first frame
-  @param    yjitter0    y-jitter in pixels of the first frame
   @param    lintable    linearity correction table
   @return   CPL_ERROR_NONE iff OK, otherwise the relevant CPL error code.
  */
@@ -1850,11 +1871,9 @@ visir_util_repack_two(const repack_framestate * fstatea,
                       cpl_frameset * products,
                       cpl_image ** pbpm,
                       cpl_image * nonlinear,
-                      double xjitter0, double yjitter0,
                       const cpl_bivector * lintable)
 {
     /* process the data */
-    cpl_errorstate cleanstate = cpl_errorstate_get();
     const repack_framestate * state = fstatea;
     int chunksize = 200;
     cpl_imagelist * aon = NULL;
@@ -1866,12 +1885,6 @@ visir_util_repack_two(const repack_framestate * fstatea,
     cpl_imagelist * aoff_next = NULL;
     cpl_imagelist * bon_next = NULL;
     cpl_imagelist * boff_next = NULL;
-    const char * chopnod_dir = visir_pfits_get_chopnod_dir(state->plist);
-
-    double dxa = fstatea->offsetx - xjitter0;
-    double dya = fstatea->offsety - yjitter0;
-    double dxb = fstateb->offsetx - xjitter0;
-    double dyb = fstateb->offsety - yjitter0;
 
     double qc_bkg_sum = 0.;
     cpl_size qc_bkg_count = 0;
@@ -1889,57 +1902,6 @@ visir_util_repack_two(const repack_framestate * fstatea,
                  "a full cycle of %d planes.", state->halfcycle * 2);
     }
 
-    /* can be missing for old spec data */
-    if (chopnod_dir == NULL) {
-        chopnod_dir = "PARALLEL";
-        cpl_errorstate_set(cleanstate);
-    }
-
-    /* try to correct the cumoffset based on throw
-     * POSANG is not a reliable mean to determine which offset has the throw
-     * added to the jitter
-     * apply heuristic that the jitter is smaller than the throw and correct
-     * those offsets that are larger than throw with a 10 pixel margin */
-    cpl_msg_info(cpl_func, "POSANG: %g; Offset: (%g, %g); Throw: %g; "
-                 "Jitterwidth %g", fstateb->posang * CPL_MATH_RAD_DEG, dxb,
-                 dyb, fstateb->pthrow, fstateb->jitterwidth);
-    if ((int)rint(fstateb->posang * CPL_MATH_RAD_DEG) % 90 == 0) {
-        if (dxb >= fstateb->pthrow - fstateb->jitterwidth - 10.) {
-            dxb -= fstateb->pthrow;
-        }
-        else if (dxb <= -(fstateb->pthrow - fstateb->jitterwidth - 10.)) {
-            dxb += fstateb->pthrow;
-        }
-        if (dyb >= fstateb->pthrow - fstateb->jitterwidth - 10.) {
-            dyb -= fstateb->pthrow;
-        }
-        else if (dyb <= -(fstateb->pthrow - fstateb->jitterwidth - 10.)) {
-            dyb += fstateb->pthrow;
-        }
-        /* spectrograph is rotated by 90 degrees, not accounted for in posang */
-        if (visir_data_is_aqu(state->datatype) &&
-            visir_pfits_get_det_name(state->plist) &&
-            strstr(visir_pfits_get_det_name(state->plist), "Spectrograph")) {
-            double tmp = dyb;
-            dyb = -dxb;
-            dxb = tmp;
-            tmp = dya;
-            dya = -dxa;
-            dxa = tmp;
-        }
-        /* remove rounding errors on no jitter */
-        dxb = fabs(dxb) < 0.001 ? 0. : dxb;
-        dyb = fabs(dyb) < 0.001 ? 0. : dyb;
-    }
-    else {
-        /* offset keywords don't seem to respect angle. assume no jitter */
-        if (fstateb->jitterwidth != 0.) {
-            cpl_msg_warning(cpl_func,
-                            "Can't do jitter correction on non normal POSANG");
-        }
-        dxb = 0.;
-        dyb = 0.;
-    }
 
     aon  = cpl_imagelist_new();
     aoff = cpl_imagelist_new();
@@ -1971,13 +1933,13 @@ visir_util_repack_two(const repack_framestate * fstatea,
 
     if (state->bkgcorrect == VISIR_SUB_CHOPCORRECT ||
         state->bkgcorrect == VISIR_SUB_NOCORRECT) {
-        prepare_output(fstatea, products, dxa, dya, dxb, dyb,
+        prepare_output(fstatea, products,
                        qc_bkg_sum / qc_bkg_count, ANOD);
-        prepare_output(fstateb, products, dxa, dya, dxb, dyb,
+        prepare_output(fstateb, products,
                        qc_bkg_sum / qc_bkg_count, BNOD);
     }
     else if (state->bkgcorrect == VISIR_SUB_CHOPNODCORRECT) {
-        prepare_output(state, products, dxa, dya, dxb, dyb,
+        prepare_output(state, products,
                        qc_bkg_sum / qc_bkg_count, ABNOD);
     }
     skip_if(0);
@@ -2008,12 +1970,12 @@ visir_util_repack_two(const repack_framestate * fstatea,
             cpl_imagelist_multiply_scalar(b, 1. / (state->dit * 4));
         }
 
-        if (visir_round_to_int(dxa) != 0 ||
-            visir_round_to_int(dya) != 0 ||
-            visir_round_to_int(dxb) != 0 ||
-            visir_round_to_int(dyb) != 0) {
-            jca = correct_jitter(a, dxa, dya);
-            jcb = correct_jitter(b, dxb, dyb);
+        if (visir_round_to_int(fstatea->offsetx) != 0 ||
+            visir_round_to_int(fstatea->offsety) != 0 ||
+            visir_round_to_int(fstateb->offsetx) != 0 ||
+            visir_round_to_int(fstateb->offsety) != 0) {
+            jca = correct_jitter(a, fstatea->offsetx, fstatea->offsety);
+            jcb = correct_jitter(b, fstateb->offsetx, fstateb->offsety);
             cpl_imagelist_subtract(jca, jcb);
             cpl_imagelist_subtract(a, b);
             save_subtract_images(fstatea, a, jca, NULL);
@@ -2108,8 +2070,7 @@ visir_util_repack_two(const repack_framestate * fstatea,
             state->bkgcorrect == VISIR_SUB_CHOPNODCORRECT) {
             cpl_boolean last_chunk = pstart + chunksize >= pend;
             skip_if(save_corrected(fstatea, fstateb,
-                                   aon, aoff, bon, boff,
-                                   dxa, dya, dxb, dyb, last_chunk));
+                                   aon, aoff, bon, boff, last_chunk));
         }
         else {
             skip_if(save_uncorrected(fstatea, fstateb, aon, aoff, bon, boff));
@@ -2146,9 +2107,10 @@ visir_util_repack_two(const repack_framestate * fstatea,
   @return   CPL_ERROR_NONE iff OK, otherwise the relevant CPL error code.
  */
 /*----------------------------------------------------------------------------*/
-static inline cpl_error_code visir_util_repack_check(const cpl_image     * self,
-                                              const cpl_imagelist * on,
-                                              const cpl_imagelist * off)
+static cpl_error_code VISIR_ATTR_UNUSED
+visir_util_repack_check(const cpl_image     * self,
+                        const cpl_imagelist * on,
+                        const cpl_imagelist * off)
 {
     /* UNUSED due to chunking */
     cpl_image          * meanon  = cpl_imagelist_collapse_create(on);
