@@ -305,6 +305,8 @@ load_images(cpl_frame * frame, const cpl_mask * bpm)
 
     end_skip;
 
+    cpl_propertylist_delete(plist);
+
     return res;
 }
 
@@ -751,18 +753,7 @@ static int visir_util_undistort(cpl_frameset            * framelist,
 
         {
             cpl_image * img = cpl_imagelist_collapse_create(laon);
-            cpl_image * flipped;
-            const cpl_size nx = cpl_image_get_size_x(img);
-            const cpl_size ny = cpl_image_get_size_y(img);
-
-            if (resol == VISIR_SPC_R_LRP) {
-                /* remove unilluminated parts that disturb wcal */
-                /* FIXME: remove hardcoding ? */
-                flipped = cpl_image_extract(img, 30, 25, nx - 30, ny - 25);
-                cpl_image_delete(img);
-                img = flipped;
-            }
-            flipped = visir_spc_flip(img, wlen, resol, data_type);
+            cpl_image * flipped = visir_spc_flip(img, wlen, resol, data_type);
             cpl_image_delete(img);
             img = flipped;
 
@@ -784,19 +775,24 @@ static int visir_util_undistort(cpl_frameset            * framelist,
     }
 
     {
-        /* remove unilluminated parts that disturb wcal */
-        /* FIXME: remove hardcoding ? */
-        cpl_image * flipped;
-        const cpl_size nx = cpl_image_get_size_x(base);
-        const cpl_size ny = cpl_image_get_size_y(base);
-
-        if (resol == VISIR_SPC_R_LRP) {
-            flipped = cpl_image_extract(base, 30, 25, nx - 30, ny - 25);
-            cpl_image_delete(base);
-            base = flipped;
+        cpl_frame * frm = cpl_frameset_find(framelist, VISIR_CALIB_LIN);
+        if (visir_data_is_aqu(data_type) && frm) {
+            cpl_msg_info(cpl_func, "Correcting linearity of skyframe");
+            cpl_frameset_insert(usedframes, cpl_frame_duplicate(frm));
+            cpl_bivector * lintable = visir_load_lintable(frm, CPL_TRUE);
+            if (lintable) {
+                cpl_image * dvals = cpl_image_cast(base, CPL_TYPE_DOUBLE);
+                /* ugly, revert normalization done by repack */
+                cpl_image_multiply_scalar(dvals, visir_pfits_get_dit(plist));
+                cpl_image * corvals = visir_linintp_values(dvals, lintable);
+                cpl_image_divide(base, corvals);
+                cpl_image_delete(dvals);
+                cpl_image_delete(corvals);
+            }
         }
+
         skip_if(visir_spc_det_warp(&base, 1, 0., 0.,  phi, ksi, eps, delta));
-        flipped = visir_spc_flip(base, wlen, resol, data_type);
+        cpl_image * flipped = visir_spc_flip(base, wlen, resol, data_type);
         cpl_image_delete(base);
         base = flipped;
     }
@@ -815,10 +811,10 @@ static int visir_util_undistort(cpl_frameset            * framelist,
     cpl_image_delete(imbpm);
     cpl_mask_delete(bpm);
     cpl_image_delete(base);
-    visir_imglist_delete(aon, NULL);
-    visir_imglist_delete(aoff, NULL);
-    visir_imglist_delete(bon, NULL);
-    visir_imglist_delete(boff, NULL);
+    visir_imglist_delete(aon, (visir_free)&cpl_propertylist_delete);
+    visir_imglist_delete(aoff, (visir_free)&cpl_propertylist_delete);
+    visir_imglist_delete(bon, (visir_free)&cpl_propertylist_delete);
+    visir_imglist_delete(boff, (visir_free)&cpl_propertylist_delete);
     cpl_frameset_delete(usedframes);
 
     return cpl_error_get_code();
