@@ -67,18 +67,6 @@ if PRO.CATG like "%IMG_STD_CATALOG%" and INSTRUME == "VISIR" then
   REFLEX.CATG = "IMG_STD_CATALOG";
 }
 
-if DPR.CATG like "%CALIB%" and DPR.TECH like "%STATIC_MASK%"  and DPR.TECH like "%IMAGE%" and INSTRUME == "VISIR" then
-{
-  DO.CATG = "STATIC_MASK_IMAGE";
-  REFLEX.CATG = "STATIC_MASK";
-}
-
-if DPR.CATG like "%CALIB%" and DPR.TECH like "%STATIC_MASK%"  and DPR.TECH like "%SPECTRUM%" and INSTRUME == "VISIR" then
-{
-  DO.CATG = "STATIC_MASK_SPECTRUM";
-  REFLEX.CATG = "STATIC_MASK";
-}
-
 if DPR.CATG like "%CALIB%" and DPR.TECH == "STATIC_MASK" and INSTRUME == "VISIR" then
 {
   DO.CATG = "STATIC_MASK";
@@ -136,43 +124,28 @@ if PRO.CATG like "%SPEC_STD_CATALOG%" and INSTRUME == "VISIR" then
   REFLEX.CATG = "SPEC_STD_CATALOG";
 }
 
-/* select bpm from calib directory for aqu data, old data uses rawdata internal
- * bpm except for burst mode where also the rawdata directoy is needs to be checked */
-select execute(ACTION_PHOT_IMG) from inputFiles where DO.CATG == "IM_CAL_PHOT" and MJD-OBS >= 56100.0
+select execute(ACTION_PHOT_IMG) from inputFiles where DO.CATG == "IM_CAL_PHOT"
   group by INS.FILT1.NAME, INS.FILT2.NAME, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_PHOT_IMG_BURST) from inputFiles where DO.CATG == "IM_CAL_PHOT_BURST" and MJD-OBS >= 56100.0
+select execute(ACTION_PHOT_IMG_BURST) from inputFiles where DO.CATG == "IM_CAL_PHOT_BURST"
   group by INS.FILT1.NAME, INS.FILT2.NAME, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_IMG) from inputFiles where (DO.CATG == "IM_OBS_CHO_NOD" or DO.CATG == "IM_OBS_CHO_NOD_JIT") and MJD-OBS >= 56100.0
+select execute(ACTION_COMBINE_IMG) from inputFiles where (DO.CATG == "IM_OBS_CHO_NOD" or DO.CATG == "IM_OBS_CHO_NOD_JIT")
   group by INS.FILT1.NAME, INS.FILT2.NAME, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_IMG_BURST) from inputFiles where (DO.CATG == "IM_OBS_CHO_NOD_BURST" or DO.CATG == "IM_OBS_CHO_NOD_JIT_BURST") and MJD-OBS >= 56100.0
-  group by INS.FILT1.NAME, INS.FILT2.NAME, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_PHOT_IMG_OLD) from inputFiles where DO.CATG == "IM_CAL_PHOT" and MJD-OBS < 56100.0
-  group by INS.FILT1.NAME, INS.FILT2.NAME, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_IMG_OLD) from inputFiles where DO.CATG like "IM_OBS_CHO_NOD%" and MJD-OBS < 56100.0
+select execute(ACTION_COMBINE_IMG_BURST) from inputFiles where (DO.CATG == "IM_OBS_CHO_NOD_BURST" or DO.CATG == "IM_OBS_CHO_NOD_JIT_BURST")
   group by INS.FILT1.NAME, INS.FILT2.NAME, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
 
-select execute(ACTION_PHOT_SPEC) from inputFiles where DO.CATG == "SPEC_CAL_PHOT" and MJD-OBS >= 56100.0
+select execute(ACTION_PHOT_SPEC) from inputFiles where DO.CATG == "SPEC_CAL_PHOT"
   group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_SPEC) from inputFiles where DO.CATG == "SPEC_OBS_LMR" and MJD-OBS >= 56100.0
+select execute(ACTION_COMBINE_SPEC) from inputFiles where DO.CATG == "SPEC_OBS_LMR"
   group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_PHOT_SPEC) from inputFiles where DO.CATG == "SPEC_CAL_PHOT_HRG" and MJD-OBS >= 56100.0
+select execute(ACTION_PHOT_SPEC) from inputFiles where DO.CATG == "SPEC_CAL_PHOT_HRG"
   group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_SPEC) from inputFiles where DO.CATG == "SPEC_OBS_HRG" and MJD-OBS >= 56100.0
-  group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-
-select execute(ACTION_PHOT_SPEC_OLD) from inputFiles where DO.CATG == "SPEC_CAL_PHOT" and MJD-OBS < 56100.0
-  group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_SPEC_OLD) from inputFiles where DO.CATG == "SPEC_OBS_LMR" and MJD-OBS < 56100.0
-  group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_PHOT_SPEC_OLD) from inputFiles where DO.CATG == "SPEC_CAL_PHOT_HRG" and MJD-OBS < 56100.0
-  group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
-select execute(ACTION_COMBINE_SPEC_OLD) from inputFiles where DO.CATG == "SPEC_OBS_HRG" and MJD-OBS < 56100.0
+select execute(ACTION_COMBINE_SPEC) from inputFiles where DO.CATG == "SPEC_OBS_HRG"
   group by INS.GRAT1.WLEN, INS.GRAT2.WLEN, INS.SLIT1.NAME, INS.RESOL, INS.PFOV, OBS.ID, OBS.NAME, OBS.TARG.NAME, DET.SEQ1.DIT, DET.DIT, DET.READ.CURNAME, TPL.START as (TPL_A,tpl);
 
 action ACTION_PHOT_IMG
 {
 minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK_IMAGE";
+select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
 minRet = 1; maxRet = 1;
 select file as IMG_STD_CATALOG from calibFiles where DO.CATG == "IMG_STD_CATALOG";
 
@@ -183,7 +156,7 @@ product IMG_PHOT_COMBINED { REFLEX.CATG = "IMG_PHOT_COMBINED"; PRO.CATG = "IMG_P
 action ACTION_COMBINE_IMG
 {
 minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK_IMAGE";
+select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
 minRet = 0; maxRet = 1;
 select file as IMG_PHOT_COMBINED from calibFiles where PRO.CATG == "IMG_PHOT_COMBINED" and (inputFile.MJD-OBS - MJD-OBS) < 0.5 and (inputFile.MJD-OBS - MJD-OBS) > -0.5 and inputFile.INS.FILT1.NAME == INS.FILT1.NAME and inputFile.INS.PFOV == INS.PFOV;
 
@@ -194,7 +167,7 @@ product IMG_OBJ_COMBINED { PRO.CATG = "IMG_OBJ_COMBINED"; PRO.EXT="tpl_0001.fits
 action ACTION_PHOT_IMG_BURST
 {
 minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK_IMAGE";
+select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
 minRet = 1; maxRet = 1;
 select file as IMG_STD_CATALOG from calibFiles where DO.CATG == "IMG_STD_CATALOG";
 
@@ -205,7 +178,7 @@ product IMG_PHOT_COMBINED { REFLEX.CATG = "IMG_PHOT_COMBINED_BURST"; PRO.CATG =
 action ACTION_COMBINE_IMG_BURST
 {
 minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK_IMAGE";
+select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
 minRet = 0; maxRet = 1;
 select file as IMG_PHOT_COMBINED from calibFiles where PRO.CATG == "IMG_PHOT_COMBINED_BURST" and (inputFile.MJD-OBS - MJD-OBS) < 0.5 and (inputFile.MJD-OBS - MJD-OBS) > -0.5 and inputFile.INS.FILT1.NAME == INS.FILT1.NAME and inputFile.INS.PFOV == INS.PFOV;
 
@@ -213,33 +186,11 @@ recipe visir_img_combine;
 product IMG_OBJ_COMBINED { PRO.CATG = "IMG_OBJ_COMBINED_BURST"; PRO.EXT="tpl_0001.fits";}
 }
 
-/* same as new data but select old detector bpm */
-action ACTION_PHOT_IMG_OLD
-{
-minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
-minRet = 1; maxRet = 1;
-select file as IMG_STD_CATALOG from calibFiles where DO.CATG == "IMG_STD_CATALOG";
-
-recipe visir_img_phot;
-product IMG_PHOT_COMBINED { REFLEX.CATG = "IMG_PHOT_COMBINED"; PRO.CATG = "IMG_PHOT_COMBINED"; PRO.EXT="tpl_0000.fits";}
-}
-
-action ACTION_COMBINE_IMG_OLD
-{
-minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
-minRet = 0; maxRet = 1;
-select file as IMG_PHOT_COMBINED from calibFiles where PRO.CATG == "IMG_PHOT_COMBINED" and (inputFile.MJD-OBS - MJD-OBS) < 0.5 and (inputFile.MJD-OBS - MJD-OBS) > -0.5 and inputFile.INS.FILT1.NAME == INS.FILT1.NAME and inputFile.INS.PFOV == INS.PFOV;
-
-recipe visir_img_combine;
-product IMG_OBJ_COMBINED { PRO.CATG = "IMG_OBJ_COMBINED"; PRO.EXT="tpl_0001.fits";}
-}
 
 action ACTION_PHOT_SPEC
 {
 minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK_SPECTRUM";
+select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
 minRet = 1; maxRet = 1;
 select file as SPEC_STD_CATALOG from calibFiles where DO.CATG == "SPEC_STD_CATALOG";
 minRet = 1; maxRet = 1;
@@ -256,38 +207,7 @@ product SPEC_PHOT_COMBINED { REFLEX.CATG = "SPEC_PHOT_COMBINED"; PRO.CATG = "SPE
 action ACTION_COMBINE_SPEC
 {
 minRet = 0; maxRet = 1;
-select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK_SPECTRUM";
-minRet = 1; maxRet = 1;
-select file as SPEC_CAL_LINES from calibFiles where DO.CATG == "SPEC_CAL_LINES";
-minRet = 1; maxRet = 1;
-select file as SPEC_CAL_QEFF from calibFiles where DO.CATG == "SPEC_CAL_QEFF";
-minRet = 0; maxRet = 1;
-select file as LINEARITY_TABLE from calibFiles where DO.CATG == "LINEARITY_TABLE";
-minRet = 0; maxRet = 1;
-select file as SPEC_PHOT_COMBINED from calibFiles where PRO.CATG == "SPEC_PHOT_COMBINED" and (inputFile.MJD-OBS - MJD-OBS) < 0.5 and (inputFile.MJD-OBS - MJD-OBS) > -0.5 and inputFile.INS.GRAT1.WLEN == INS.GRAT1.WLEN and inputFile.INS.PFOV == INS.PFOV;
-
-recipe visir_spc_obs;
-product SPEC_OBJ_COMBINED { PRO.CATG = "SPEC_OBJ_COMBINED"; PRO.EXT="tpl_0001.fits";}
-}
-
-/* same as new data no bpm needed (included in rawdata) */
-action ACTION_PHOT_SPEC_OLD
-{
-minRet = 1; maxRet = 1;
-select file as SPEC_STD_CATALOG from calibFiles where DO.CATG == "SPEC_STD_CATALOG";
-minRet = 1; maxRet = 1;
-select file as SPEC_CAL_LINES from calibFiles where DO.CATG == "SPEC_CAL_LINES";
-minRet = 1; maxRet = 1;
-select file as SPEC_CAL_QEFF from calibFiles where DO.CATG == "SPEC_CAL_QEFF";
-minRet = 0; maxRet = 1;
-select file as LINEARITY_TABLE from calibFiles where DO.CATG == "LINEARITY_TABLE";
-
-recipe visir_spc_phot;
-product SPEC_PHOT_COMBINED { REFLEX.CATG = "SPEC_PHOT_COMBINED"; PRO.CATG = "SPEC_PHOT_COMBINED"; PRO.EXT="tpl_0000.fits";}
-}
-
-action ACTION_COMBINE_SPEC_OLD
-{
+select file as STATIC_MASK from calibFiles where DO.CATG == "STATIC_MASK";
 minRet = 1; maxRet = 1;
 select file as SPEC_CAL_LINES from calibFiles where DO.CATG == "SPEC_CAL_LINES";
 minRet = 1; maxRet = 1;
