@@ -87,10 +87,17 @@ int visir_dfs_set_groups(cpl_frameset * set)
                                          "Frame %d has no tag", i);
         else if (!strcmp(tag, VISIR_IMG_ACHRO_RAW) ||
                  !strcmp(tag, VISIR_IMG_COMBINE_CN) ||
+                 !strcmp(tag, VISIR_IMG_COMBINE_CN_BURST) ||
                  !strcmp(tag, VISIR_IMG_COMBINE_CNJ) ||
+                 !strcmp(tag, VISIR_IMG_COMBINE_CNJ_BURST) ||
                  !strcmp(tag, VISIR_IMG_COMBINE_CJ) ||
                  !strcmp(tag, VISIR_IMG_COMBINE_NJ) ||
                  !strcmp(tag, VISIR_IMG_COMBINE_DJ) ||
+                 !strcmp(tag, VISIR_IMG_CAL_PHOT) ||
+                 !strcmp(tag, VISIR_IMG_CAL_PHOT_PP) ||
+                 !strcmp(tag, VISIR_IMG_CAL_PHOT_BURST) ||
+                 !strcmp(tag, VISIR_IMG_CAL_OBJ) ||
+                 !strcmp(tag, VISIR_IMG_CAL_OBJ_BURST) ||
                  !strcmp(tag, VISIR_IMG_FF_RAW) ||
                  !strcmp(tag, VISIR_IMG_TECH_FF_RAW) ||
                  !strcmp(tag, VISIR_IMG_FOCFWHM_RAW) ||
@@ -98,6 +105,8 @@ int visir_dfs_set_groups(cpl_frameset * set)
                  !strcmp(tag, VISIR_IMG_PFOV_BIN) ||
                  !strcmp(tag, VISIR_IMG_PFOV_TEL) ||
                  !strcmp(tag, VISIR_IMG_PHOT_RAW) ||
+                 !strcmp(tag, VISIR_IMG_PHOT_COMBINED_PROCATG) ||
+                 !strcmp(tag, VISIR_IMG_COADDED_IMG) ||
                  !strcmp(tag, VISIR_IMG_PSF_RAW) ||
                  !strcmp(tag, VISIR_IMG_TRANS_RAW) ||
                  !strcmp(tag, VISIR_IMG_DARK_RAW) ||
@@ -110,6 +119,7 @@ int visir_dfs_set_groups(cpl_frameset * set)
                  !strcmp(tag, VISIR_SPC_PHOT_PP) ||
                  !strcmp(tag, VISIR_SPC_PHOT_ECH_RAW) ||
                  !strcmp(tag, VISIR_SPC_PHOT_ECH_PP) ||
+                 !strcmp(tag, VISIR_SPC_OBS_ECH_PP) ||
                  !strcmp(tag, VISIR_SPC_WCAL_ECH_RAW) ||
                  !strcmp(tag, VISIR_SPC_WCAL_RAW) ||
                  !strcmp(tag, VISIR_SPC_FF_RAW) ||
@@ -118,6 +128,30 @@ int visir_dfs_set_groups(cpl_frameset * set)
                  !strcmp(tag, VISIR_IMG_LINES_ASCII) ||
                  !strcmp(tag, VISIR_SPC_LINES_ASCII) ||
                  !strcmp(tag, VISIR_SPC_QEFF_ASCII) ||
+                 !strcmp(tag, VISIR_SAM_CAL_N_RAW) ||
+                 !strcmp(tag, VISIR_SAM_CAL_CN_RAW) ||
+                 !strcmp(tag, VISIR_SAM_CAL_NJ_RAW) ||
+                 !strcmp(tag, VISIR_SAM_CAL_CNJ_RAW) ||
+                 !strcmp(tag, VISIR_CORO_CAL_CNJ_RAW) ||
+                 !strcmp(tag, VISIR_SAM_OBS_N_RAW) ||
+                 !strcmp(tag, VISIR_SAM_OBS_CN_RAW) ||
+                 !strcmp(tag, VISIR_SAM_OBS_NJ_RAW) ||
+                 !strcmp(tag, VISIR_SAM_OBS_CNJ_RAW) ||
+                 !strcmp(tag, VISIR_CORO_OBS_CNJ_RAW) ||
+                 !strcmp(tag, VISIR_UTIL_QC_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_A_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_B_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_A_ON_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_A_OFF_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_B_ON_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_MEAN_B_OFF_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_A_ON_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_A_OFF_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_B_ON_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_REPACK_B_OFF_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_DETECT_SHIFT_PROCATG) ||
+                 !strcmp(tag, VISIR_UTIL_DETECT_SHIFT_TEMPLATE_PROCATG) ||
                  !strcmp(tag, VISIR_UTIL_INPUTS_RAW) ||
                  !strcmp(tag, VISIR_UTIL_CORRECTED) ||
                  !strcmp(tag, VISIR_UTIL_NODDED) ||
@@ -136,6 +170,8 @@ int visir_dfs_set_groups(cpl_frameset * set)
         else if (!strcmp(tag, VISIR_CALIB_FLAT) ||
                  !strcmp(tag, VISIR_CALIB_BPM) ||
                  !strcmp(tag, VISIR_CALIB_STATIC_MASK) ||
+                 !strcmp(tag, VISIR_CALIB_STATIC_MASK_IMG) ||
+                 !strcmp(tag, VISIR_CALIB_STATIC_MASK_SPC) ||
                  !strcmp(tag, VISIR_CALIB_STDSTAR_IMG) ||
                  !strcmp(tag, VISIR_CALIB_STDSTAR_SPC) ||
                  !strcmp(tag, VISIR_CALIB_LINES_SPC) ||
@@ -163,6 +199,33 @@ int visir_dfs_set_groups(cpl_frameset * set)
     return cpl_error_get_code();
 }
 
+const char *
+visir_dfs_output_catg(const char * inpcatg, const char * pipecatg)
+{
+    int phot = 0;
+    if (!strcmp(pipecatg, VISIR_IMG_PHOT_ONEBEAM_PROCATG) ||
+        !strcmp(pipecatg, VISIR_IMG_PHOT_COMBINED_PROCATG)) {
+        phot = 1;
+    }
+    if (!strcmp(inpcatg, VISIR_ACQ_CNJ)) {
+        if (phot) {
+            return "ACQ_IMG_PHOT_COMBINED";
+        }
+        else {
+            return "ACQ_IMG_OBJ_COMBINED";
+        }
+    }
+    else if (!strcmp(inpcatg, VISIR_IMG_CAL_PHOT_BURST)) {
+        return VISIR_IMG_PHOT_COMBINED_PROCATG"_BURST";
+    }
+    else if (!strcmp(inpcatg, VISIR_IMG_CAL_OBJ_BURST) ||
+             !strcmp(inpcatg, VISIR_IMG_COMBINE_CN_BURST) ||
+             !strcmp(inpcatg, VISIR_IMG_COMBINE_CNJ_BURST)) {
+        return VISIR_IMG_OBJ_COMBINED_PROCATG"_BURST";
+    }
+    return pipecatg;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Check the tags in a frameset (group raw only)
