@@ -150,6 +150,11 @@ cpl_error_code visir_get_data_type(const cpl_frame * frame,
                                    const cpl_propertylist * plist,
                                    visir_data_type * ptype, cpl_size * pnext);
 
+cpl_bivector * visir_load_lintable(cpl_frame * linframe, cpl_boolean is_spec);
+
+cpl_image *
+visir_load_bpm(cpl_frame * frm, visir_data_type dtype, cpl_boolean is_spec);
+
 cpl_error_code visir_load_cube2_split(cpl_imagelist *, cpl_imagelist *,
                                       const irplib_framelist *, const int,
                                       const int, const int);
@@ -177,6 +182,6 @@ visir_chopnod_mode visir_img_find_beam(cpl_propertylist        *,
 
 cpl_error_code visir_img_find_beam_two(cpl_propertylist *, const cpl_image  *,
                                        const cpl_image  *, double, double, double,
-                                       double [], double [], cpl_boolean);
+                                       double [], double []);
 
 #endif
