@@ -239,6 +239,22 @@ int visir_pfits_get_chop_ncycles(const cpl_propertylist * self)
     return visir_pfits_get_int("ESO DET CHOP NCYCLES");
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    The adapter position angle in rad
+  @param    self       property list to read from
+  @return   Chopping position angle in rad
+ */
+/*----------------------------------------------------------------------------*/
+double visir_pfits_get_ada_posang(const cpl_propertylist * self)
+{
+    if (!cpl_propertylist_has(self, VISIR_PFITS_DOUBLE_ADA_POSANG)) {
+        return 0.;
+    }
+    return CPL_MATH_RAD_DEG *
+        cpl_propertylist_get_double(self, VISIR_PFITS_DOUBLE_ADA_POSANG);
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    The cumulative offset in X
@@ -457,7 +473,8 @@ const char * visir_pfits_get_grat1_name(const cpl_propertylist * self)
 /*----------------------------------------------------------------------------*/
 const char * visir_pfits_get_insmode(const cpl_propertylist * self)
 {
-    return visir_pfits_get_string("ESO INS MODE");
+    const char * mode = visir_pfits_get_string("ESO INS MODE");
+    return mode ? mode : "(none)";
 }
 
 /*----------------------------------------------------------------------------*/
